from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CsZero:
	"""CsZero commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("csZero", core, parent)

	def set(self, ssp_bch_cs_zero: int, cellNull=repcap.CellNull.Nr0, ssPbchNull=repcap.SsPbchNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:SSPBch<ST0>:MIB:CSZero \n
		Snippet: driver.source.bb.nr5G.node.cell.sspbch.mib.csZero.set(ssp_bch_cs_zero = 1, cellNull = repcap.CellNull.Nr0, ssPbchNull = repcap.SsPbchNull.Default) \n
		Sets the common control resource set (CORESET) of the initial downlink BWP. \n
			:param ssp_bch_cs_zero: integer Range: 0 to 15
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param ssPbchNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')"""
		param = Conversions.decimal_value_to_str(ssp_bch_cs_zero)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		ssPbchNull_cmd_val = self._base.get_repcap_cmd_value(ssPbchNull, repcap.SsPbchNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{ssPbchNull_cmd_val}:MIB:CSZero {param}')

	def get(self, cellNull=repcap.CellNull.Nr0, ssPbchNull=repcap.SsPbchNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:SSPBch<ST0>:MIB:CSZero \n
		Snippet: value: int = driver.source.bb.nr5G.node.cell.sspbch.mib.csZero.get(cellNull = repcap.CellNull.Nr0, ssPbchNull = repcap.SsPbchNull.Default) \n
		Sets the common control resource set (CORESET) of the initial downlink BWP. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param ssPbchNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')
			:return: ssp_bch_cs_zero: integer Range: 0 to 15"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		ssPbchNull_cmd_val = self._base.get_repcap_cmd_value(ssPbchNull, repcap.SsPbchNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{ssPbchNull_cmd_val}:MIB:CSZero?')
		return Conversions.str_to_int(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fa:
	"""Fa commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fa", core, parent)

	# noinspection PyTypeChecker
	def get_fr_allocation(self) -> enums.EutraTcwfReqAlloc:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:FA:FRALlocation \n
		Snippet: value: enums.EutraTcwfReqAlloc = driver.source.bb.eutra.tcw.fa.get_fr_allocation() \n
		Determines the frequency position of the wanted and interfering signal. \n
			:return: frequency_alloc: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:FA:FRALlocation?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwfReqAlloc)

	def set_fr_allocation(self, frequency_alloc: enums.EutraTcwfReqAlloc) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:FA:FRALlocation \n
		Snippet: driver.source.bb.eutra.tcw.fa.set_fr_allocation(frequency_alloc = enums.EutraTcwfReqAlloc.HIGHer) \n
		Determines the frequency position of the wanted and interfering signal. \n
			:param frequency_alloc: HIGHer| LOWer
		"""
		param = Conversions.enum_scalar_to_str(frequency_alloc, enums.EutraTcwfReqAlloc)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:FA:FRALlocation {param}')

	# noinspection PyTypeChecker
	def get_rb_allocation(self) -> enums.EutraTcwfReqAlloc:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:FA:RBALlocation \n
		Snippet: value: enums.EutraTcwfReqAlloc = driver.source.bb.eutra.tcw.fa.get_rb_allocation() \n
		Determines the frequency position of the wanted and interfering signal. \n
			:return: res_block_alloc: HIGHer| LOWer
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:TCW:FA:RBALlocation?')
		return Conversions.str_to_scalar_enum(response, enums.EutraTcwfReqAlloc)

	def set_rb_allocation(self, res_block_alloc: enums.EutraTcwfReqAlloc) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:TCW:FA:RBALlocation \n
		Snippet: driver.source.bb.eutra.tcw.fa.set_rb_allocation(res_block_alloc = enums.EutraTcwfReqAlloc.HIGHer) \n
		Determines the frequency position of the wanted and interfering signal. \n
			:param res_block_alloc: HIGHer| LOWer
		"""
		param = Conversions.enum_scalar_to_str(res_block_alloc, enums.EutraTcwfReqAlloc)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:TCW:FA:RBALlocation {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Impulsive:
	"""Impulsive commands group definition. 7 total commands, 1 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("impulsive", core, parent)

	@property
	def burst(self):
		"""burst commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_burst'):
			from .Burst import Burst
			self._burst = Burst(self._core, self._base)
		return self._burst

	def get_ci(self) -> float:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:CI \n
		Snippet: value: float = driver.source.noise.impulsive.get_ci() \n
		Specifies the ratio of the wanted signal (C) to the impulsive noise signal (I) . \n
			:return: ipls_ci: float Range: -35 to 60
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:IMPulsive:CI?')
		return Conversions.str_to_float(response)

	def set_ci(self, ipls_ci: float) -> None:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:CI \n
		Snippet: driver.source.noise.impulsive.set_ci(ipls_ci = 1.0) \n
		Specifies the ratio of the wanted signal (C) to the impulsive noise signal (I) . \n
			:param ipls_ci: float Range: -35 to 60
		"""
		param = Conversions.decimal_value_to_str(ipls_ci)
		self._core.io.write(f'SOURce<HwInstance>:NOISe:IMPulsive:CI {param}')

	def get_frame(self) -> float:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:FRAMe \n
		Snippet: value: float = driver.source.noise.impulsive.get_frame() \n
		Sets the time intervals at which the bursts occur. \n
			:return: ipls_frame_duration: float Range: 0.1E-3 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:IMPulsive:FRAMe?')
		return Conversions.str_to_float(response)

	def set_frame(self, ipls_frame_duration: float) -> None:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:FRAMe \n
		Snippet: driver.source.noise.impulsive.set_frame(ipls_frame_duration = 1.0) \n
		Sets the time intervals at which the bursts occur. \n
			:param ipls_frame_duration: float Range: 0.1E-3 to 1
		"""
		param = Conversions.decimal_value_to_str(ipls_frame_duration)
		self._core.io.write(f'SOURce<HwInstance>:NOISe:IMPulsive:FRAMe {param}')

	def get_max_space(self) -> float:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:MAXSpace \n
		Snippet: value: float = driver.source.noise.impulsive.get_max_space() \n
		If more than 1 pulse per burst are enabled (method RsSmw.Source.Noise.Impulsive.pulsee.g. 2) , sets the minimum/maximum
		spacing between 2 pulses within a burst. \n
			:return: ipls_space_max: float Range: 0.25E-6 to 0.01
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:IMPulsive:MAXSpace?')
		return Conversions.str_to_float(response)

	def set_max_space(self, ipls_space_max: float) -> None:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:MAXSpace \n
		Snippet: driver.source.noise.impulsive.set_max_space(ipls_space_max = 1.0) \n
		If more than 1 pulse per burst are enabled (method RsSmw.Source.Noise.Impulsive.pulsee.g. 2) , sets the minimum/maximum
		spacing between 2 pulses within a burst. \n
			:param ipls_space_max: float Range: 0.25E-6 to 0.01
		"""
		param = Conversions.decimal_value_to_str(ipls_space_max)
		self._core.io.write(f'SOURce<HwInstance>:NOISe:IMPulsive:MAXSpace {param}')

	def get_min_space(self) -> float:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:MINSpace \n
		Snippet: value: float = driver.source.noise.impulsive.get_min_space() \n
		If more than 1 pulse per burst are enabled (method RsSmw.Source.Noise.Impulsive.pulsee.g. 2) , sets the minimum/maximum
		spacing between 2 pulses within a burst. \n
			:return: ipls_min_space: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:IMPulsive:MINSpace?')
		return Conversions.str_to_float(response)

	def set_min_space(self, ipls_min_space: float) -> None:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:MINSpace \n
		Snippet: driver.source.noise.impulsive.set_min_space(ipls_min_space = 1.0) \n
		If more than 1 pulse per burst are enabled (method RsSmw.Source.Noise.Impulsive.pulsee.g. 2) , sets the minimum/maximum
		spacing between 2 pulses within a burst. \n
			:param ipls_min_space: float Range: 0.25E-6 to 0.01
		"""
		param = Conversions.decimal_value_to_str(ipls_min_space)
		self._core.io.write(f'SOURce<HwInstance>:NOISe:IMPulsive:MINSpace {param}')

	def get_pulse(self) -> int:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:PULSe \n
		Snippet: value: int = driver.source.noise.impulsive.get_pulse() \n
		Sets the number of noise pulses per burst. \n
			:return: ipls_pulse: integer Range: 1 to 65535
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:IMPulsive:PULSe?')
		return Conversions.str_to_int(response)

	def set_pulse(self, ipls_pulse: int) -> None:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:PULSe \n
		Snippet: driver.source.noise.impulsive.set_pulse(ipls_pulse = 1) \n
		Sets the number of noise pulses per burst. \n
			:param ipls_pulse: integer Range: 1 to 65535
		"""
		param = Conversions.decimal_value_to_str(ipls_pulse)
		self._core.io.write(f'SOURce<HwInstance>:NOISe:IMPulsive:PULSe {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:[STATe] \n
		Snippet: value: bool = driver.source.noise.impulsive.get_state() \n
		Enables or disables the impulsive noise generator. \n
			:return: impulsive_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:IMPulsive:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, impulsive_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:NOISe:IMPulsive:[STATe] \n
		Snippet: driver.source.noise.impulsive.set_state(impulsive_state = False) \n
		Enables or disables the impulsive noise generator. \n
			:param impulsive_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(impulsive_state)
		self._core.io.write(f'SOURce<HwInstance>:NOISe:IMPulsive:STATe {param}')

	def clone(self) -> 'Impulsive':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Impulsive(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, pr_erors_mode: enums.PseudorangeMode, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GLONass:PRERrors:MODE \n
		Snippet: driver.source.bb.gnss.svid.glonass.prErrors.mode.set(pr_erors_mode = enums.PseudorangeMode.CONStant, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets how the pseudorange errors are defined. \n
			:param pr_erors_mode: FSBas| CONStant| PROFile FSBas Extracted form the imported SBAS corrections, if [:SOURcehw]:BB:GNSS:ECModeSYNC. CONStant Set with the command [:SOURcehw]:BB:GNSS:SVIDch:GPS:PRERrors:VALue PROFile Defined with the command pairs [:SOURcehw]:BB:GNSS:SVIDch:GPS:PRERrors:PROFilegr:REFerence and [:SOURcehw]:BB:GNSS:SVIDch:GPS:PRERrors:PROFilegr:VALue
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')"""
		param = Conversions.enum_scalar_to_str(pr_erors_mode, enums.PseudorangeMode)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GLONass:PRERrors:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> enums.PseudorangeMode:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GLONass:PRERrors:MODE \n
		Snippet: value: enums.PseudorangeMode = driver.source.bb.gnss.svid.glonass.prErrors.mode.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets how the pseudorange errors are defined. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: pr_erors_mode: FSBas| CONStant| PROFile FSBas Extracted form the imported SBAS corrections, if [:SOURcehw]:BB:GNSS:ECModeSYNC. CONStant Set with the command [:SOURcehw]:BB:GNSS:SVIDch:GPS:PRERrors:VALue PROFile Defined with the command pairs [:SOURcehw]:BB:GNSS:SVIDch:GPS:PRERrors:PROFilegr:REFerence and [:SOURcehw]:BB:GNSS:SVIDch:GPS:PRERrors:PROFilegr:VALue"""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GLONass:PRERrors:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.PseudorangeMode)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StdLength:
	"""StdLength commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("stdLength", core, parent)

	def get(self, std_frame_data_len: int, commandBlock=repcap.CommandBlock.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:STDLength \n
		Snippet: value: int = driver.source.bb.nfc.cblock.apGeneric.stdLength.get(std_frame_data_len = 1, commandBlock = repcap.CommandBlock.Default) \n
		Shows the total length of a standard frame in bytes. \n
			:param std_frame_data_len: integer Range: 1 to 10
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: std_frame_data_len: integer Range: 1 to 10"""
		param = Conversions.decimal_value_to_str(std_frame_data_len)
		commandBlock_cmd_val = self._base.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:STDLength? {param}')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cell:
	"""Cell commands group definition. 17 total commands, 14 Sub-groups, 0 group commands
	Repeated Capability: CellNull, default value after init: CellNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cell", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_cellNull_get', 'repcap_cellNull_set', repcap.CellNull.Nr0)

	def repcap_cellNull_set(self, enum_value: repcap.CellNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to CellNull.Default
		Default value after init: CellNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_cellNull_get(self) -> repcap.CellNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def cdmType(self):
		"""cdmType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cdmType'):
			from .CdmType import CdmType
			self._cdmType = CdmType(self._core, self._base)
		return self._cdmType

	@property
	def config(self):
		"""config commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_config'):
			from .Config import Config
			self._config = Config(self._core, self._base)
		return self._config

	@property
	def dwpts(self):
		"""dwpts commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dwpts'):
			from .Dwpts import Dwpts
			self._dwpts = Dwpts(self._core, self._base)
		return self._dwpts

	@property
	def frDensity(self):
		"""frDensity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frDensity'):
			from .FrDensity import FrDensity
			self._frDensity = FrDensity(self._core, self._base)
		return self._frDensity

	@property
	def nap(self):
		"""nap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nap'):
			from .Nap import Nap
			self._nap = Nap(self._core, self._base)
		return self._nap

	@property
	def ncfg(self):
		"""ncfg commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncfg'):
			from .Ncfg import Ncfg
			self._ncfg = Ncfg(self._core, self._base)
		return self._ncfg

	@property
	def pow(self):
		"""pow commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pow'):
			from .Pow import Pow
			self._pow = Pow(self._core, self._base)
		return self._pow

	@property
	def scid(self):
		"""scid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scid'):
			from .Scid import Scid
			self._scid = Scid(self._core, self._base)
		return self._scid

	@property
	def sfDelta(self):
		"""sfDelta commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfDelta'):
			from .SfDelta import SfDelta
			self._sfDelta = SfDelta(self._core, self._base)
		return self._sfDelta

	@property
	def sfi(self):
		"""sfi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfi'):
			from .Sfi import Sfi
			self._sfi = Sfi(self._core, self._base)
		return self._sfi

	@property
	def sft(self):
		"""sft commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sft'):
			from .Sft import Sft
			self._sft = Sft(self._core, self._base)
		return self._sft

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def transcomb(self):
		"""transcomb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_transcomb'):
			from .Transcomb import Transcomb
			self._transcomb = Transcomb(self._core, self._base)
		return self._transcomb

	@property
	def zprs(self):
		"""zprs commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_zprs'):
			from .Zprs import Zprs
			self._zprs = Zprs(self._core, self._base)
		return self._zprs

	def clone(self) -> 'Cell':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Cell(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fblock:
	"""Fblock commands group definition. 224 total commands, 63 Sub-groups, 2 group commands
	Repeated Capability: FrameBlock, default value after init: FrameBlock.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fblock", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_frameBlock_get', 'repcap_frameBlock_set', repcap.FrameBlock.Nr1)

	def repcap_frameBlock_set(self, enum_value: repcap.FrameBlock) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FrameBlock.Default
		Default value after init: FrameBlock.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_frameBlock_get(self) -> repcap.FrameBlock:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def append(self):
		"""append commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_append'):
			from .Append import Append
			self._append = Append(self._core, self._base)
		return self._append

	@property
	def bchg(self):
		"""bchg commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bchg'):
			from .Bchg import Bchg
			self._bchg = Bchg(self._core, self._base)
		return self._bchg

	@property
	def bcSmoothing(self):
		"""bcSmoothing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bcSmoothing'):
			from .BcSmoothing import BcSmoothing
			self._bcSmoothing = BcSmoothing(self._core, self._base)
		return self._bcSmoothing

	@property
	def bdcm(self):
		"""bdcm commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bdcm'):
			from .Bdcm import Bdcm
			self._bdcm = Bdcm(self._core, self._base)
		return self._bdcm

	@property
	def bfConfiguration(self):
		"""bfConfiguration commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_bfConfiguration'):
			from .BfConfiguration import BfConfiguration
			self._bfConfiguration = BfConfiguration(self._core, self._base)
		return self._bfConfiguration

	@property
	def bmcs(self):
		"""bmcs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bmcs'):
			from .Bmcs import Bmcs
			self._bmcs = Bmcs(self._core, self._base)
		return self._bmcs

	@property
	def boost(self):
		"""boost commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_boost'):
			from .Boost import Boost
			self._boost = Boost(self._core, self._base)
		return self._boost

	@property
	def bssColor(self):
		"""bssColor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bssColor'):
			from .BssColor import BssColor
			self._bssColor = BssColor(self._core, self._base)
		return self._bssColor

	@property
	def cbiNonht(self):
		"""cbiNonht commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cbiNonht'):
			from .CbiNonht import CbiNonht
			self._cbiNonht = CbiNonht(self._core, self._base)
		return self._cbiNonht

	@property
	def cch1(self):
		"""cch1 commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cch1'):
			from .Cch1 import Cch1
			self._cch1 = Cch1(self._core, self._base)
		return self._cch1

	@property
	def cch2(self):
		"""cch2 commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cch2'):
			from .Cch2 import Cch2
			self._cch2 = Cch2(self._core, self._base)
		return self._cch2

	@property
	def cenru(self):
		"""cenru commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cenru'):
			from .Cenru import Cenru
			self._cenru = Cenru(self._core, self._base)
		return self._cenru

	@property
	def color(self):
		"""color commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_color'):
			from .Color import Color
			self._color = Color(self._core, self._base)
		return self._color

	@property
	def curpe(self):
		"""curpe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_curpe'):
			from .Curpe import Curpe
			self._curpe = Curpe(self._core, self._base)
		return self._curpe

	@property
	def data(self):
		"""data commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import Data
			self._data = Data(self._core, self._base)
		return self._data

	@property
	def dbinonht(self):
		"""dbinonht commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dbinonht'):
			from .Dbinonht import Dbinonht
			self._dbinonht = Dbinonht(self._core, self._base)
		return self._dbinonht

	@property
	def doppler(self):
		"""doppler commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_doppler'):
			from .Doppler import Doppler
			self._doppler = Doppler(self._core, self._base)
		return self._doppler

	@property
	def esStream(self):
		"""esStream commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_esStream'):
			from .EsStream import EsStream
			self._esStream = EsStream(self._core, self._base)
		return self._esStream

	@property
	def fcount(self):
		"""fcount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fcount'):
			from .Fcount import Fcount
			self._fcount = Fcount(self._core, self._base)
		return self._fcount

	@property
	def guard(self):
		"""guard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_guard'):
			from .Guard import Guard
			self._guard = Guard(self._core, self._base)
		return self._guard

	@property
	def insert(self):
		"""insert commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_insert'):
			from .Insert import Insert
			self._insert = Insert(self._core, self._base)
		return self._insert

	@property
	def itime(self):
		"""itime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_itime'):
			from .Itime import Itime
			self._itime = Itime(self._core, self._base)
		return self._itime

	@property
	def link(self):
		"""link commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_link'):
			from .Link import Link
			self._link = Link(self._core, self._base)
		return self._link

	@property
	def logFile(self):
		"""logFile commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_logFile'):
			from .LogFile import LogFile
			self._logFile = LogFile(self._core, self._base)
		return self._logFile

	@property
	def logging(self):
		"""logging commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_logging'):
			from .Logging import Logging
			self._logging = Logging(self._core, self._base)
		return self._logging

	@property
	def mac(self):
		"""mac commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_mac'):
			from .Mac import Mac
			self._mac = Mac(self._core, self._base)
		return self._mac

	@property
	def maxPe(self):
		"""maxPe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_maxPe'):
			from .MaxPe import MaxPe
			self._maxPe = MaxPe(self._core, self._base)
		return self._maxPe

	@property
	def mu(self):
		"""mu commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_mu'):
			from .Mu import Mu
			self._mu = Mu(self._core, self._base)
		return self._mu

	@property
	def muMimo(self):
		"""muMimo commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_muMimo'):
			from .MuMimo import MuMimo
			self._muMimo = MuMimo(self._core, self._base)
		return self._muMimo

	@property
	def ntps(self):
		"""ntps commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ntps'):
			from .Ntps import Ntps
			self._ntps = Ntps(self._core, self._base)
		return self._ntps

	@property
	def paid(self):
		"""paid commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_paid'):
			from .Paid import Paid
			self._paid = Paid(self._core, self._base)
		return self._paid

	@property
	def paste(self):
		"""paste commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_paste'):
			from .Paste import Paste
			self._paste = Paste(self._core, self._base)
		return self._paste

	@property
	def ped(self):
		"""ped commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ped'):
			from .Ped import Ped
			self._ped = Ped(self._core, self._base)
		return self._ped

	@property
	def pformat(self):
		"""pformat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pformat'):
			from .Pformat import Pformat
			self._pformat = Pformat(self._core, self._base)
		return self._pformat

	@property
	def pfpFactor(self):
		"""pfpFactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pfpFactor'):
			from .PfpFactor import PfpFactor
			self._pfpFactor = PfpFactor(self._core, self._base)
		return self._pfpFactor

	@property
	def piType(self):
		"""piType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_piType'):
			from .PiType import PiType
			self._piType = PiType(self._core, self._base)
		return self._piType

	@property
	def plcp(self):
		"""plcp commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_plcp'):
			from .Plcp import Plcp
			self._plcp = Plcp(self._core, self._base)
		return self._plcp

	@property
	def pmode(self):
		"""pmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pmode'):
			from .Pmode import Pmode
			self._pmode = Pmode(self._core, self._base)
		return self._pmode

	@property
	def pofdma(self):
		"""pofdma commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pofdma'):
			from .Pofdma import Pofdma
			self._pofdma = Pofdma(self._core, self._base)
		return self._pofdma

	@property
	def ppuncturing(self):
		"""ppuncturing commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ppuncturing'):
			from .Ppuncturing import Ppuncturing
			self._ppuncturing = Ppuncturing(self._core, self._base)
		return self._ppuncturing

	@property
	def preamble(self):
		"""preamble commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_preamble'):
			from .Preamble import Preamble
			self._preamble = Preamble(self._core, self._base)
		return self._preamble

	@property
	def prtype(self):
		"""prtype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prtype'):
			from .Prtype import Prtype
			self._prtype = Prtype(self._core, self._base)
		return self._prtype

	@property
	def psdu(self):
		"""psdu commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_psdu'):
			from .Psdu import Psdu
			self._psdu = Psdu(self._core, self._base)
		return self._psdu

	@property
	def right106Tone(self):
		"""right106Tone commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_right106Tone'):
			from .Right106Tone import Right106Tone
			self._right106Tone = Right106Tone(self._core, self._base)
		return self._right106Tone

	@property
	def segment(self):
		"""segment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_segment'):
			from .Segment import Segment
			self._segment = Segment(self._core, self._base)
		return self._segment

	@property
	def smapping(self):
		"""smapping commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_smapping'):
			from .Smapping import Smapping
			self._smapping = Smapping(self._core, self._base)
		return self._smapping

	@property
	def smoothing(self):
		"""smoothing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_smoothing'):
			from .Smoothing import Smoothing
			self._smoothing = Smoothing(self._core, self._base)
		return self._smoothing

	@property
	def spareUse(self):
		"""spareUse commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spareUse'):
			from .SpareUse import SpareUse
			self._spareUse = SpareUse(self._core, self._base)
		return self._spareUse

	@property
	def sstream(self):
		"""sstream commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sstream'):
			from .Sstream import Sstream
			self._sstream = Sstream(self._core, self._base)
		return self._sstream

	@property
	def standard(self):
		"""standard commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_standard'):
			from .Standard import Standard
			self._standard = Standard(self._core, self._base)
		return self._standard

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def stbc(self):
		"""stbc commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_stbc'):
			from .Stbc import Stbc
			self._stbc = Stbc(self._core, self._base)
		return self._stbc

	@property
	def stStream(self):
		"""stStream commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_stStream'):
			from .StStream import StStream
			self._stStream = StStream(self._core, self._base)
		return self._stStream

	@property
	def symDuration(self):
		"""symDuration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symDuration'):
			from .SymDuration import SymDuration
			self._symDuration = SymDuration(self._core, self._base)
		return self._symDuration

	@property
	def tdWindowing(self):
		"""tdWindowing commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tdWindowing'):
			from .TdWindowing import TdWindowing
			self._tdWindowing = TdWindowing(self._core, self._base)
		return self._tdWindowing

	@property
	def tmode(self):
		"""tmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tmode'):
			from .Tmode import Tmode
			self._tmode = Tmode(self._core, self._base)
		return self._tmode

	@property
	def ttime(self):
		"""ttime commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttime'):
			from .Ttime import Ttime
			self._ttime = Ttime(self._core, self._base)
		return self._ttime

	@property
	def txopDuration(self):
		"""txopDuration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_txopDuration'):
			from .TxopDuration import TxopDuration
			self._txopDuration = TxopDuration(self._core, self._base)
		return self._txopDuration

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePy
			self._typePy = TypePy(self._core, self._base)
		return self._typePy

	@property
	def uindex(self):
		"""uindex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uindex'):
			from .Uindex import Uindex
			self._uindex = Uindex(self._core, self._base)
		return self._uindex

	@property
	def uindication(self):
		"""uindication commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_uindication'):
			from .Uindication import Uindication
			self._uindication = Uindication(self._core, self._base)
		return self._uindication

	@property
	def ulen(self):
		"""ulen commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ulen'):
			from .Ulen import Ulen
			self._ulen = Ulen(self._core, self._base)
		return self._ulen

	@property
	def user(self):
		"""user commands group. 21 Sub-classes, 0 commands."""
		if not hasattr(self, '_user'):
			from .User import User
			self._user = User(self._core, self._base)
		return self._user

	def copy(self, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:COPY \n
		Snippet: driver.source.bb.wlnn.fblock.copy(frameBlock = repcap.FrameBlock.Default) \n
		Copies the selected frame block. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:COPY')

	def copy_with_opc(self, frameBlock=repcap.FrameBlock.Default) -> None:
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:COPY \n
		Snippet: driver.source.bb.wlnn.fblock.copy_with_opc(frameBlock = repcap.FrameBlock.Default) \n
		Copies the selected frame block. \n
		Same as copy, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:COPY')

	def delete(self, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:DELete \n
		Snippet: driver.source.bb.wlnn.fblock.delete(frameBlock = repcap.FrameBlock.Default) \n
		Deletes the selected frame block. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:DELete')

	def delete_with_opc(self, frameBlock=repcap.FrameBlock.Default) -> None:
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:DELete \n
		Snippet: driver.source.bb.wlnn.fblock.delete_with_opc(frameBlock = repcap.FrameBlock.Default) \n
		Deletes the selected frame block. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:DELete')

	def clone(self) -> 'Fblock':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Fblock(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Predefined:
	"""Predefined commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("predefined", core, parent)

	# noinspection PyTypeChecker
	def get_category(self) -> enums.FadDssUsrVehCat:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:CATegory \n
		Snippet: value: enums.FadDssUsrVehCat = driver.source.fsimulator.dsSimulation.user.rx.vehicle.predefined.get_category() \n
		No command help available \n
			:return: veh_pred_cat: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:CATegory?')
		return Conversions.str_to_scalar_enum(response, enums.FadDssUsrVehCat)

	def set_category(self, veh_pred_cat: enums.FadDssUsrVehCat) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:CATegory \n
		Snippet: driver.source.fsimulator.dsSimulation.user.rx.vehicle.predefined.set_category(veh_pred_cat = enums.FadDssUsrVehCat.AIR) \n
		No command help available \n
			:param veh_pred_cat: No help available
		"""
		param = Conversions.enum_scalar_to_str(veh_pred_cat, enums.FadDssUsrVehCat)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:CATegory {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.FadDssVehTypeAll:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:TYPE \n
		Snippet: value: enums.FadDssVehTypeAll = driver.source.fsimulator.dsSimulation.user.rx.vehicle.predefined.get_type_py() \n
		No command help available \n
			:return: veh_pred_type: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FadDssVehTypeAll)

	def set_type_py(self, veh_pred_type: enums.FadDssVehTypeAll) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:TYPE \n
		Snippet: driver.source.fsimulator.dsSimulation.user.rx.vehicle.predefined.set_type_py(veh_pred_type = enums.FadDssVehTypeAll.AHELicopter) \n
		No command help available \n
			:param veh_pred_type: No help available
		"""
		param = Conversions.enum_scalar_to_str(veh_pred_type, enums.FadDssVehTypeAll)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:VEHicle:PREDefined:TYPE {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UsrTime:
	"""UsrTime commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("usrTime", core, parent)

	def set(self, usr_time: str, groupNull=repcap.GroupNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:STEReo:GRPS:GT<ST0>:USRTime \n
		Snippet: driver.source.bb.stereo.grps.gt.usrTime.set(usr_time = '1', groupNull = repcap.GroupNull.Default) \n
		No command help available \n
			:param usr_time: No help available
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Gt')"""
		param = Conversions.value_to_quoted_str(usr_time)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:STEReo:GRPS:GT{groupNull_cmd_val}:USRTime {param}')

	def get(self, groupNull=repcap.GroupNull.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:STEReo:GRPS:GT<ST0>:USRTime \n
		Snippet: value: str = driver.source.bb.stereo.grps.gt.usrTime.get(groupNull = repcap.GroupNull.Default) \n
		No command help available \n
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Gt')
			:return: usr_time: No help available"""
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:STEReo:GRPS:GT{groupNull_cmd_val}:USRTime?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mccw:
	"""Mccw commands group definition. 43 total commands, 5 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mccw", core, parent)

	@property
	def carrier(self):
		"""carrier commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_carrier'):
			from .Carrier import Carrier
			self._carrier = Carrier(self._core, self._base)
		return self._carrier

	@property
	def cfactor(self):
		"""cfactor commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_cfactor'):
			from .Cfactor import Cfactor
			self._cfactor = Cfactor(self._core, self._base)
		return self._cfactor

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import Clock
			self._clock = Clock(self._core, self._base)
		return self._clock

	@property
	def edit(self):
		"""edit commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_edit'):
			from .Edit import Edit
			self._edit = Edit(self._core, self._base)
		return self._edit

	@property
	def trigger(self):
		"""trigger commands group. 5 Sub-classes, 4 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import Trigger
			self._trigger = Trigger(self._core, self._base)
		return self._trigger

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:MCCW:PRESet \n
		Snippet: driver.source.bb.mccw.preset() \n
		Sets all multi carrier signal parameters to their default values. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:MCCW:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:MCCW:PRESet \n
		Snippet: driver.source.bb.mccw.preset_with_opc() \n
		Sets all multi carrier signal parameters to their default values. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:MCCW:PRESet')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:MCCW:STATe \n
		Snippet: value: bool = driver.source.bb.mccw.get_state() \n
		Enables/disables the multi carrier CW signal. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:MCCW:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:MCCW:STATe \n
		Snippet: driver.source.bb.mccw.set_state(state = False) \n
		Enables/disables the multi carrier CW signal. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:MCCW:STATe {param}')

	def clone(self) -> 'Mccw':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mccw(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, val_enable: bool, notchFilter=repcap.NotchFilter.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:NOTCh<CH>:STATe \n
		Snippet: driver.source.bb.oneweb.notch.state.set(val_enable = False, notchFilter = repcap.NotchFilter.Default) \n
		Enables the particular notch. \n
			:param val_enable: 0| 1| OFF| ON
			:param notchFilter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')"""
		param = Conversions.bool_to_str(val_enable)
		notchFilter_cmd_val = self._base.get_repcap_cmd_value(notchFilter, repcap.NotchFilter)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:NOTCh{notchFilter_cmd_val}:STATe {param}')

	def get(self, notchFilter=repcap.NotchFilter.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:NOTCh<CH>:STATe \n
		Snippet: value: bool = driver.source.bb.oneweb.notch.state.get(notchFilter = repcap.NotchFilter.Default) \n
		Enables the particular notch. \n
			:param notchFilter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')
			:return: val_enable: 0| 1| OFF| ON"""
		notchFilter_cmd_val = self._base.get_repcap_cmd_value(notchFilter, repcap.NotchFilter)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:NOTCh{notchFilter_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sattenuation:
	"""Sattenuation commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Slot, default value after init: Slot.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sattenuation", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_slot_get', 'repcap_slot_set', repcap.Slot.Nr1)

	def repcap_slot_set(self, enum_value: repcap.Slot) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Slot.Default
		Default value after init: Slot.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_slot_get(self) -> repcap.Slot:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, sattenuation: float, slot=repcap.Slot.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SATTenuation<CH> \n
		Snippet: driver.source.bb.tetra.sattenuation.set(sattenuation = 1.0, slot = repcap.Slot.Default) \n
		Enters four different values for level attenuation. The frame editor can be used to set the level attenuation for the
		four slots to one of these predefined values independently of one another. The entered value determines the slot output
		power (slot power = RF power - attenuation) . 0 dB attenuation corresponds to 'Slot Level' = Full. This feature is
		provided to set a sequence of slots to different levels in order to measure transmission stability. The frame editor is
		likewise used to assign the 'Slot Level' attribute Attenuated to individual slots. \n
			:param sattenuation: float Range: 0 to 50
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sattenuation')"""
		param = Conversions.decimal_value_to_str(sattenuation)
		slot_cmd_val = self._base.get_repcap_cmd_value(slot, repcap.Slot)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:SATTenuation{slot_cmd_val} {param}')

	def get(self, slot=repcap.Slot.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SATTenuation<CH> \n
		Snippet: value: float = driver.source.bb.tetra.sattenuation.get(slot = repcap.Slot.Default) \n
		Enters four different values for level attenuation. The frame editor can be used to set the level attenuation for the
		four slots to one of these predefined values independently of one another. The entered value determines the slot output
		power (slot power = RF power - attenuation) . 0 dB attenuation corresponds to 'Slot Level' = Full. This feature is
		provided to set a sequence of slots to different levels in order to measure transmission stability. The frame editor is
		likewise used to assign the 'Slot Level' attribute Attenuated to individual slots. \n
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sattenuation')
			:return: sattenuation: float Range: 0 to 50"""
		slot_cmd_val = self._base.get_repcap_cmd_value(slot, repcap.Slot)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TETRa:SATTenuation{slot_cmd_val}?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Sattenuation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sattenuation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dexchange:
	"""Dexchange commands group definition. 8 total commands, 2 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dexchange", core, parent)

	@property
	def afile(self):
		"""afile commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_afile'):
			from .Afile import Afile
			self._afile = Afile(self._core, self._base)
		return self._afile

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._base)
		return self._execute

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.DexchMode:
		"""SCPI: [SOURce<HW>]:CORRection:DEXChange:MODE \n
		Snippet: value: enums.DexchMode = driver.source.correction.dexchange.get_mode() \n
		Determines import or export of a user correction list. Specify the source or destination file with the command method
		RsSmw.Source.Correction.Dexchange.select. \n
			:return: mode: IMPort| EXPort
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:DEXChange:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.DexchMode)

	def set_mode(self, mode: enums.DexchMode) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:DEXChange:MODE \n
		Snippet: driver.source.correction.dexchange.set_mode(mode = enums.DexchMode.EXPort) \n
		Determines import or export of a user correction list. Specify the source or destination file with the command method
		RsSmw.Source.Correction.Dexchange.select. \n
			:param mode: IMPort| EXPort
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.DexchMode)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:DEXChange:MODE {param}')

	def get_select(self) -> str:
		"""SCPI: [SOURce<HW>]:CORRection:DEXChange:SELect \n
		Snippet: value: str = driver.source.correction.dexchange.get_select() \n
		Selects the ASCII file for import or export, containing a user correction list. \n
			:return: filename: string Filename or complete file path; file extension can be omitted.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:CORRection:DEXChange:SELect?')
		return trim_str_response(response)

	def set_select(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:CORRection:DEXChange:SELect \n
		Snippet: driver.source.correction.dexchange.set_select(filename = '1') \n
		Selects the ASCII file for import or export, containing a user correction list. \n
			:param filename: string Filename or complete file path; file extension can be omitted.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:CORRection:DEXChange:SELect {param}')

	def clone(self) -> 'Dexchange':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dexchange(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cnav:
	"""Cnav commands group definition. 45 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cnav", core, parent)

	@property
	def ccorrection(self):
		"""ccorrection commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccorrection'):
			from .Ccorrection import Ccorrection
			self._ccorrection = Ccorrection(self._core, self._base)
		return self._ccorrection

	@property
	def ephemeris(self):
		"""ephemeris commands group. 20 Sub-classes, 0 commands."""
		if not hasattr(self, '_ephemeris'):
			from .Ephemeris import Ephemeris
			self._ephemeris = Ephemeris(self._core, self._base)
		return self._ephemeris

	def clone(self) -> 'Cnav':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Cnav(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	def set(self, power: float, vdbTransmitter=repcap.VdbTransmitter.Default, timeSlot=repcap.TimeSlot.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:SCH:TS<ST>:POWer \n
		Snippet: driver.source.bb.gbas.vdb.sch.ts.power.set(power = 1.0, vdbTransmitter = repcap.VdbTransmitter.Default, timeSlot = repcap.TimeSlot.Default) \n
		Sets the relative power of a VDB per time slot (TS) . \n
			:param power: float Range: -21 to 0
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:param timeSlot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ts')"""
		param = Conversions.decimal_value_to_str(power)
		vdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		timeSlot_cmd_val = self._base.get_repcap_cmd_value(timeSlot, repcap.TimeSlot)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:SCH:TS{timeSlot_cmd_val}:POWer {param}')

	def get(self, vdbTransmitter=repcap.VdbTransmitter.Default, timeSlot=repcap.TimeSlot.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GBAS:VDB<CH>:SCH:TS<ST>:POWer \n
		Snippet: value: float = driver.source.bb.gbas.vdb.sch.ts.power.get(vdbTransmitter = repcap.VdbTransmitter.Default, timeSlot = repcap.TimeSlot.Default) \n
		Sets the relative power of a VDB per time slot (TS) . \n
			:param vdbTransmitter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Vdb')
			:param timeSlot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ts')
			:return: power: float Range: -21 to 0"""
		vdbTransmitter_cmd_val = self._base.get_repcap_cmd_value(vdbTransmitter, repcap.VdbTransmitter)
		timeSlot_cmd_val = self._base.get_repcap_cmd_value(timeSlot, repcap.TimeSlot)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GBAS:VDB{vdbTransmitter_cmd_val}:SCH:TS{timeSlot_cmd_val}:POWer?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rdata:
	"""Rdata commands group definition. 9 total commands, 9 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rdata", core, parent)

	@property
	def hoppingParam(self):
		"""hoppingParam commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hoppingParam'):
			from .HoppingParam import HoppingParam
			self._hoppingParam = HoppingParam(self._core, self._base)
		return self._hoppingParam

	@property
	def nsubbands(self):
		"""nsubbands commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nsubbands'):
			from .Nsubbands import Nsubbands
			self._nsubbands = Nsubbands(self._core, self._base)
		return self._nsubbands

	@property
	def offsetInd(self):
		"""offsetInd commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offsetInd'):
			from .OffsetInd import OffsetInd
			self._offsetInd = OffsetInd(self._core, self._base)
		return self._offsetInd

	@property
	def prbNumber(self):
		"""prbNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prbNumber'):
			from .PrbNumber import PrbNumber
			self._prbNumber = PrbNumber(self._core, self._base)
		return self._prbNumber

	@property
	def prbStart(self):
		"""prbStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prbStart'):
			from .PrbStart import PrbStart
			self._prbStart = PrbStart(self._core, self._base)
		return self._prbStart

	@property
	def prend(self):
		"""prend commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prend'):
			from .Prend import Prend
			self._prend = Prend(self._core, self._base)
		return self._prend

	@property
	def rbOffset(self):
		"""rbOffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rbOffset'):
			from .RbOffset import RbOffset
			self._rbOffset = RbOffset(self._core, self._base)
		return self._rbOffset

	@property
	def sfbmp(self):
		"""sfbmp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfbmp'):
			from .Sfbmp import Sfbmp
			self._sfbmp = Sfbmp(self._core, self._base)
		return self._sfbmp

	@property
	def trptSubset(self):
		"""trptSubset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trptSubset'):
			from .TrptSubset import TrptSubset
			self._trptSubset = TrptSubset(self._core, self._base)
		return self._trptSubset

	def clone(self) -> 'Rdata':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rdata(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.Utilities import trim_str_response
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 6 total commands, 0 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	def get_dselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:DSELection \n
		Snippet: value: str = driver.source.bb.dvb.dvbx.data.get_dselection() \n
		Selects an existing data list, transport file (TS) or GSE file from the default or from the specific directory.
			INTRO_CMD_HELP: Selects the clock source: \n
			- TS files are files with extension *.gts, *.ts, or *.trp.
			- GSE files are files with extension *.gse
			- Data lists are files with extension *.dm_iqd
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: fselection: string Filename incl. file extension or complete file path
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:DATA:DSELection?')
		return trim_str_response(response)

	def set_dselection(self, fselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:DSELection \n
		Snippet: driver.source.bb.dvb.dvbx.data.set_dselection(fselection = '1') \n
		Selects an existing data list, transport file (TS) or GSE file from the default or from the specific directory.
			INTRO_CMD_HELP: Selects the clock source: \n
			- TS files are files with extension *.gts, *.ts, or *.trp.
			- GSE files are files with extension *.gse
			- Data lists are files with extension *.dm_iqd
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param fselection: string Filename incl. file extension or complete file path
		"""
		param = Conversions.value_to_quoted_str(fselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:DATA:DSELection {param}')

	def get_gselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:GSELection \n
		Snippet: value: str = driver.source.bb.dvb.dvbx.data.get_gselection() \n
		Selects an existing data list, transport file (TS) or GSE file from the default or from the specific directory.
			INTRO_CMD_HELP: Selects the clock source: \n
			- TS files are files with extension *.gts, *.ts, or *.trp.
			- GSE files are files with extension *.gse
			- Data lists are files with extension *.dm_iqd
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: fselection: string Filename incl. file extension or complete file path
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:DATA:GSELection?')
		return trim_str_response(response)

	def set_gselection(self, fselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:GSELection \n
		Snippet: driver.source.bb.dvb.dvbx.data.set_gselection(fselection = '1') \n
		Selects an existing data list, transport file (TS) or GSE file from the default or from the specific directory.
			INTRO_CMD_HELP: Selects the clock source: \n
			- TS files are files with extension *.gts, *.ts, or *.trp.
			- GSE files are files with extension *.gse
			- Data lists are files with extension *.dm_iqd
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param fselection: string Filename incl. file extension or complete file path
		"""
		param = Conversions.value_to_quoted_str(fselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:DATA:GSELection {param}')

	def get_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:LENGth \n
		Snippet: value: int = driver.source.bb.dvb.dvbx.data.get_length() \n
		Sets the data length. \n
			:return: dlength: integer Range: 1 to 65536, Unit: Bytes
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:DATA:LENGth?')
		return Conversions.str_to_int(response)

	def set_length(self, dlength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:LENGth \n
		Snippet: driver.source.bb.dvb.dvbx.data.set_length(dlength = 1) \n
		Sets the data length. \n
			:param dlength: integer Range: 1 to 65536, Unit: Bytes
		"""
		param = Conversions.decimal_value_to_str(dlength)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:DATA:LENGth {param}')

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Pattern: List[str]: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def get_pattern(self) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.dvb.dvbx.data.get_pattern() \n
		Sets the the bit pattern. \n
			:return: structure: for return value, see the help for PatternStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:DVB:DVBX:DATA:PATTern?', self.__class__.PatternStruct())

	def set_pattern(self, value: PatternStruct) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:PATTern \n
		Snippet: driver.source.bb.dvb.dvbx.data.set_pattern(value = PatternStruct()) \n
		Sets the the bit pattern. \n
			:param value: see the help for PatternStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce<HwInstance>:BB:DVB:DVBX:DATA:PATTern', value)

	def get_tselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:TSELection \n
		Snippet: value: str = driver.source.bb.dvb.dvbx.data.get_tselection() \n
		Selects an existing data list, transport file (TS) or GSE file from the default or from the specific directory.
			INTRO_CMD_HELP: Selects the clock source: \n
			- TS files are files with extension *.gts, *.ts, or *.trp.
			- GSE files are files with extension *.gse
			- Data lists are files with extension *.dm_iqd
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: fselection: string Filename incl. file extension or complete file path
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:DATA:TSELection?')
		return trim_str_response(response)

	def set_tselection(self, fselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA:TSELection \n
		Snippet: driver.source.bb.dvb.dvbx.data.set_tselection(fselection = '1') \n
		Selects an existing data list, transport file (TS) or GSE file from the default or from the specific directory.
			INTRO_CMD_HELP: Selects the clock source: \n
			- TS files are files with extension *.gts, *.ts, or *.trp.
			- GSE files are files with extension *.gse
			- Data lists are files with extension *.dm_iqd
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param fselection: string Filename incl. file extension or complete file path
		"""
		param = Conversions.value_to_quoted_str(fselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:DATA:TSELection {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.DvbDataSource:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA \n
		Snippet: value: enums.DvbDataSource = driver.source.bb.dvb.dvbx.data.get_value() \n
		Selects the data source. \n
			:return: data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| TFILe| GFILe PATTern To set the bit pattern, use the command [:SOURcehw]:BB:DVB:DVBS|DVBX:DATA:PATTern. DLISt|TFILe|GFILe To select the data list, TS file or the GSE file, use the command [:SOURcehw]:BB:DVB:DVBS|DVBX:DATA:DSELection|TSELection|GSELection.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBX:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DvbDataSource)

	def set_value(self, data: enums.DvbDataSource) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBX:DATA \n
		Snippet: driver.source.bb.dvb.dvbx.data.set_value(data = enums.DvbDataSource.DLISt) \n
		Selects the data source. \n
			:param data: ZERO| ONE| PATTern| PN9| PN11| PN15| PN16| PN20| PN21| PN23| DLISt| TFILe| GFILe PATTern To set the bit pattern, use the command [:SOURcehw]:BB:DVB:DVBS|DVBX:DATA:PATTern. DLISt|TFILe|GFILe To select the data list, TS file or the GSE file, use the command [:SOURcehw]:BB:DVB:DVBS|DVBX:DATA:DSELection|TSELection|GSELection.
		"""
		param = Conversions.enum_scalar_to_str(data, enums.DvbDataSource)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBX:DATA {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Coordinates:
	"""Coordinates commands group definition. 5 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("coordinates", core, parent)

	@property
	def decimal(self):
		"""decimal commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_decimal'):
			from .Decimal import Decimal
			self._decimal = Decimal(self._core, self._base)
		return self._decimal

	@property
	def dms(self):
		"""dms commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_dms'):
			from .Dms import Dms
			self._dms = Dms(self._core, self._base)
		return self._dms

	# noinspection PyTypeChecker
	def get_rframe(self) -> enums.RefFrame:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:LOCation:COORdinates:RFRame \n
		Snippet: value: enums.RefFrame = driver.source.bb.gnss.adGeneration.gps.location.coordinates.get_rframe() \n
		Sets the reference frame. \n
			:return: reference_frame: PZ90| WGS84
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:LOCation:COORdinates:RFRame?')
		return Conversions.str_to_scalar_enum(response, enums.RefFrame)

	def set_rframe(self, reference_frame: enums.RefFrame) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:LOCation:COORdinates:RFRame \n
		Snippet: driver.source.bb.gnss.adGeneration.gps.location.coordinates.set_rframe(reference_frame = enums.RefFrame.PZ90) \n
		Sets the reference frame. \n
			:param reference_frame: PZ90| WGS84
		"""
		param = Conversions.enum_scalar_to_str(reference_frame, enums.RefFrame)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:LOCation:COORdinates:RFRame {param}')

	def clone(self) -> 'Coordinates':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Coordinates(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reference:
	"""Reference commands group definition. 9 total commands, 2 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reference", core, parent)

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import Delay
			self._delay = Delay(self._core, self._base)
		return self._delay

	@property
	def fdoppler(self):
		"""fdoppler commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_fdoppler'):
			from .Fdoppler import Fdoppler
			self._fdoppler = Fdoppler(self._core, self._base)
		return self._fdoppler

	def get_fratio(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:FRATio \n
		Snippet: value: float = driver.source.fsimulator.tcInterferer.reference.get_fratio() \n
		Sets the ratio of the actual Doppler frequency to the set Doppler frequency for the reference and moving path with 2
		channel interferer fading. \n
			:return: fratio: float Range: -1 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:FRATio?')
		return Conversions.str_to_float(response)

	def set_fratio(self, fratio: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:FRATio \n
		Snippet: driver.source.fsimulator.tcInterferer.reference.set_fratio(fratio = 1.0) \n
		Sets the ratio of the actual Doppler frequency to the set Doppler frequency for the reference and moving path with 2
		channel interferer fading. \n
			:param fratio: float Range: -1 to 1
		"""
		param = Conversions.decimal_value_to_str(fratio)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:FRATio {param}')

	def get_loss(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:LOSS \n
		Snippet: value: float = driver.source.fsimulator.tcInterferer.reference.get_loss() \n
		Seta the loss of the reference and moving path with 2 channel interferer fading. \n
			:return: loss: float Range: 0 to 50
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:LOSS?')
		return Conversions.str_to_float(response)

	def set_loss(self, loss: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:LOSS \n
		Snippet: driver.source.fsimulator.tcInterferer.reference.set_loss(loss = 1.0) \n
		Seta the loss of the reference and moving path with 2 channel interferer fading. \n
			:param loss: float Range: 0 to 50
		"""
		param = Conversions.decimal_value_to_str(loss)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:LOSS {param}')

	# noinspection PyTypeChecker
	def get_mmode(self) -> enums.Fad2CitfMode:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:MMODe \n
		Snippet: value: enums.Fad2CitfMode = driver.source.fsimulator.tcInterferer.reference.get_mmode() \n
		Selects the type of moving applied to the moving path. \n
			:return: mmode: SLIDing| HOPPing
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:MMODe?')
		return Conversions.str_to_scalar_enum(response, enums.Fad2CitfMode)

	def set_mmode(self, mmode: enums.Fad2CitfMode) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:MMODe \n
		Snippet: driver.source.fsimulator.tcInterferer.reference.set_mmode(mmode = enums.Fad2CitfMode.HOPPing) \n
		Selects the type of moving applied to the moving path. \n
			:param mmode: SLIDing| HOPPing
		"""
		param = Conversions.enum_scalar_to_str(mmode, enums.Fad2CitfMode)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:MMODe {param}')

	# noinspection PyTypeChecker
	def get_profile(self) -> enums.FadingProfileB:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:PROFile \n
		Snippet: value: enums.FadingProfileB = driver.source.fsimulator.tcInterferer.reference.get_profile() \n
		Sets the fading profile to be used for the reference and moving path with 2 channel interferer fading. \n
			:return: profile: SPATh| PDOPpler| RAYLeigh
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:PROFile?')
		return Conversions.str_to_scalar_enum(response, enums.FadingProfileB)

	def set_profile(self, profile: enums.FadingProfileB) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:PROFile \n
		Snippet: driver.source.fsimulator.tcInterferer.reference.set_profile(profile = enums.FadingProfileB.BELLindoor) \n
		Sets the fading profile to be used for the reference and moving path with 2 channel interferer fading. \n
			:param profile: SPATh| PDOPpler| RAYLeigh
		"""
		param = Conversions.enum_scalar_to_str(profile, enums.FadingProfileB)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:PROFile {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:STATe \n
		Snippet: value: bool = driver.source.fsimulator.tcInterferer.reference.get_state() \n
		Activate the reference and moving path of the 2 channel interferer fading configuration. The 2 channel interferer fading
		configuration and the fading simulator must be switched on separately, see [:SOURce<hw>]:FSIMulator:TCINterferer[:STATe]
		and .[:SOURce<hw>]:FSIMulator[:STATe] \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:TCINterferer:REFerence:STATe \n
		Snippet: driver.source.fsimulator.tcInterferer.reference.set_state(state = False) \n
		Activate the reference and moving path of the 2 channel interferer fading configuration. The 2 channel interferer fading
		configuration and the fading simulator must be switched on separately, see [:SOURce<hw>]:FSIMulator:TCINterferer[:STATe]
		and .[:SOURce<hw>]:FSIMulator[:STATe] \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:TCINterferer:REFerence:STATe {param}')

	def clone(self) -> 'Reference':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Reference(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.TpcMode, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:DPCCh:TPC:MODE \n
		Snippet: driver.source.bb.w3Gpp.mstation.dpcch.tpc.mode.set(mode = enums.TpcMode.D2B, mobileStation = repcap.MobileStation.Default) \n
		Selects the TPC (Transmit Power Control) mode.
		The command sets the slot format ([:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPCCh:SFORmat) in conjunction with the set TFCI
		status ([:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPCCh:TFCI:STATe) and the FBI Mode
		([:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPCCh:FBI:MODE) to the associated values. \n
			:param mode: D2B| D4B D2B A TPC field with a length of 2 bits is used. D4B (enabled only for instruments equipped with R&S SMW-K83) A TPC field with a length of 4 bits is used. A 4 bits long TPC field can be selected, only for Slot Format 4 and disabled FBI and TFCI fields.
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.enum_scalar_to_str(mode, enums.TpcMode)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:DPCCh:TPC:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, mobileStation=repcap.MobileStation.Default) -> enums.TpcMode:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:DPCCh:TPC:MODE \n
		Snippet: value: enums.TpcMode = driver.source.bb.w3Gpp.mstation.dpcch.tpc.mode.get(mobileStation = repcap.MobileStation.Default) \n
		Selects the TPC (Transmit Power Control) mode.
		The command sets the slot format ([:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPCCh:SFORmat) in conjunction with the set TFCI
		status ([:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPCCh:TFCI:STATe) and the FBI Mode
		([:SOURce<hw>]:BB:W3GPp:MSTation<st>:DPCCh:FBI:MODE) to the associated values. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: mode: D2B| D4B D2B A TPC field with a length of 2 bits is used. D4B (enabled only for instruments equipped with R&S SMW-K83) A TPC field with a length of 4 bits is used. A 4 bits long TPC field can be selected, only for Slot Format 4 and disabled FBI and TFCI fields."""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:DPCCh:TPC:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TpcMode)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.Utilities import trim_str_response
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Acad:
	"""Acad commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("acad", core, parent)

	# noinspection PyTypeChecker
	class ApatternStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Dpattern: List[str]: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct('Dpattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Dpattern: List[str] = None
			self.Bitcount: int = None

	def get_apattern(self) -> ApatternStruct:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:APATtern \n
		Snippet: value: ApatternStruct = driver.source.bb.btooth.econfiguration.pconfiguration.acad.get_apattern() \n
		Specifies user-defined pattern.
		The settings is relevant for [:SOURce<hw>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACADPATTern \n
			:return: structure: for return value, see the help for ApatternStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:APATtern?', self.__class__.ApatternStruct())

	def set_apattern(self, value: ApatternStruct) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:APATtern \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.acad.set_apattern(value = ApatternStruct()) \n
		Specifies user-defined pattern.
		The settings is relevant for [:SOURce<hw>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACADPATTern \n
			:param value: see the help for ApatternStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:APATtern', value)

	def get_aselection(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:ASELection \n
		Snippet: value: str = driver.source.bb.btooth.econfiguration.pconfiguration.acad.get_aselection() \n
		Specifies data list file. The settings is relevant for [:SOURce<hw>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACADDLISt \n
			:return: dselection: string Path and file name.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:ASELection?')
		return trim_str_response(response)

	def set_aselection(self, dselection: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:ASELection \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.acad.set_aselection(dselection = '1') \n
		Specifies data list file. The settings is relevant for [:SOURce<hw>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACADDLISt \n
			:param dselection: string Path and file name.
		"""
		param = Conversions.value_to_quoted_str(dselection)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:ASELection {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.DataSourceB:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD \n
		Snippet: value: enums.DataSourceB = driver.source.bb.btooth.econfiguration.pconfiguration.acad.get_value() \n
		Specifies the pattern source used for additional controller advertising data (ACAD) . \n
			:return: data: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt ALL0 / ALL1 All 0 or all 1 pattern PATTern User-defined pattern. The pattern can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:APATtern PNxx Pseudo-random bit sequences (PRBS) of a length of xx bits. The length in bit can be 9, 11, 15, 16, 20, 21, or 23. DLISt Internal ACAD data list is used. The data list can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:ASELection
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD?')
		return Conversions.str_to_scalar_enum(response, enums.DataSourceB)

	def set_value(self, data: enums.DataSourceB) -> None:
		"""SCPI: [SOURce<HW>]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD \n
		Snippet: driver.source.bb.btooth.econfiguration.pconfiguration.acad.set_value(data = enums.DataSourceB.ALL0) \n
		Specifies the pattern source used for additional controller advertising data (ACAD) . \n
			:param data: ALL0| ALL1| PATTern| PN09| PN11| PN15| PN16| PN20| PN21| PN23| DLISt ALL0 / ALL1 All 0 or all 1 pattern PATTern User-defined pattern. The pattern can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:APATtern PNxx Pseudo-random bit sequences (PRBS) of a length of xx bits. The length in bit can be 9, 11, 15, 16, 20, 21, or 23. DLISt Internal ACAD data list is used. The data list can be specified via: [:SOURcehw]:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD:ASELection
		"""
		param = Conversions.enum_scalar_to_str(data, enums.DataSourceB)
		self._core.io.write(f'SOURce<HwInstance>:BB:BTOoth:ECONfiguration:PCONfiguration:ACAD {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Foffset:
	"""Foffset commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("foffset", core, parent)

	def set(self, frequency_offset: int, ceLevel=repcap.CeLevel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:EMTC:CELV<CH0>:FOFFset \n
		Snippet: driver.source.bb.eutra.uplink.prach.emtc.celv.foffset.set(frequency_offset = 1, ceLevel = repcap.CeLevel.Default) \n
		Sets a frequency offset in terms of resource blocks. \n
			:param frequency_offset: integer Range: 0 to 94
			:param ceLevel: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Celv')"""
		param = Conversions.decimal_value_to_str(frequency_offset)
		ceLevel_cmd_val = self._base.get_repcap_cmd_value(ceLevel, repcap.CeLevel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:EMTC:CELV{ceLevel_cmd_val}:FOFFset {param}')

	def get(self, ceLevel=repcap.CeLevel.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:PRACh:EMTC:CELV<CH0>:FOFFset \n
		Snippet: value: int = driver.source.bb.eutra.uplink.prach.emtc.celv.foffset.get(ceLevel = repcap.CeLevel.Default) \n
		Sets a frequency offset in terms of resource blocks. \n
			:param ceLevel: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Celv')
			:return: frequency_offset: integer Range: 0 to 94"""
		ceLevel_cmd_val = self._base.get_repcap_cmd_value(ceLevel, repcap.CeLevel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:PRACh:EMTC:CELV{ceLevel_cmd_val}:FOFFset?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Icoder:
	"""Icoder commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("icoder", core, parent)

	# noinspection PyTypeChecker
	def get_rate(self) -> enums.DvbCoderate:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBT:[HP]:ICODer:RATE \n
		Snippet: value: enums.DvbCoderate = driver.source.bb.dvb.dvbt.hp.icoder.get_rate() \n
		Selects the code rate of the inner coder. \n
			:return: rate: CR1D2| CR2D3| CR3D4| CR5D6| CR7D8
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBT:HP:ICODer:RATE?')
		return Conversions.str_to_scalar_enum(response, enums.DvbCoderate)

	def set_rate(self, rate: enums.DvbCoderate) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBT:[HP]:ICODer:RATE \n
		Snippet: driver.source.bb.dvb.dvbt.hp.icoder.set_rate(rate = enums.DvbCoderate.CR1D2) \n
		Selects the code rate of the inner coder. \n
			:param rate: CR1D2| CR2D3| CR3D4| CR5D6| CR7D8
		"""
		param = Conversions.enum_scalar_to_str(rate, enums.DvbCoderate)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBT:HP:ICODer:RATE {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBT:[HP]:ICODer:[STATe] \n
		Snippet: value: bool = driver.source.bb.dvb.dvbt.hp.icoder.get_state() \n
		Activates/deactivates the inner coder. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:DVB:DVBT:HP:ICODer:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:DVB:DVBT:[HP]:ICODer:[STATe] \n
		Snippet: driver.source.bb.dvb.dvbt.hp.icoder.set_state(state = False) \n
		Activates/deactivates the inner coder. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:DVB:DVBT:HP:ICODer:STATe {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Poffset:
	"""Poffset commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("poffset", core, parent)

	def set(self, ue_cc_power_offs: float, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default, rowNull=repcap.RowNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:UE<ST>:CELL<DIR0>:ROW<CH0>:POFFset \n
		Snippet: driver.source.bb.v5G.uplink.ue.cell.row.poffset.set(ue_cc_power_offs = 1.0, userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default, rowNull = repcap.RowNull.Default) \n
		No command help available \n
			:param ue_cc_power_offs: float Range: -80 to 10
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')"""
		param = Conversions.decimal_value_to_str(ue_cc_power_offs)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:ROW{rowNull_cmd_val}:POFFset {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, cellNull=repcap.CellNull.Default, rowNull=repcap.RowNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:UE<ST>:CELL<DIR0>:ROW<CH0>:POFFset \n
		Snippet: value: float = driver.source.bb.v5G.uplink.ue.cell.row.poffset.get(userEquipment = repcap.UserEquipment.Default, cellNull = repcap.CellNull.Default, rowNull = repcap.RowNull.Default) \n
		No command help available \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
			:return: ue_cc_power_offs: float Range: -80 to 10"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:UL:UE{userEquipment_cmd_val}:CELL{cellNull_cmd_val}:ROW{rowNull_cmd_val}:POFFset?')
		return Conversions.str_to_float(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ptrs:
	"""Ptrs commands group definition. 8 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ptrs", core, parent)

	@property
	def epre(self):
		"""epre commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_epre'):
			from .Epre import Epre
			self._epre = Epre(self._core, self._base)
		return self._epre

	@property
	def mcs1(self):
		"""mcs1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs1'):
			from .Mcs1 import Mcs1
			self._mcs1 = Mcs1(self._core, self._base)
		return self._mcs1

	@property
	def mcs2(self):
		"""mcs2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs2'):
			from .Mcs2 import Mcs2
			self._mcs2 = Mcs2(self._core, self._base)
		return self._mcs2

	@property
	def mcs3(self):
		"""mcs3 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcs3'):
			from .Mcs3 import Mcs3
			self._mcs3 = Mcs3(self._core, self._base)
		return self._mcs3

	@property
	def rb0(self):
		"""rb0 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb0'):
			from .Rb0 import Rb0
			self._rb0 = Rb0(self._core, self._base)
		return self._rb0

	@property
	def rb1(self):
		"""rb1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rb1'):
			from .Rb1 import Rb1
			self._rb1 = Rb1(self._core, self._base)
		return self._rb1

	@property
	def reof(self):
		"""reof commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reof'):
			from .Reof import Reof
			self._reof = Reof(self._core, self._base)
		return self._reof

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'Ptrs':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ptrs(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Macceleration:
	"""Macceleration commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("macceleration", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration:STATe \n
		Snippet: value: bool = driver.source.fsimulator.dsSimulation.user.rx.trajectory.tdf.macceleration.get_state() \n
		No command help available \n
			:return: traj_tdf_acc_state: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, traj_tdf_acc_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration:STATe \n
		Snippet: driver.source.fsimulator.dsSimulation.user.rx.trajectory.tdf.macceleration.set_state(traj_tdf_acc_state = False) \n
		No command help available \n
			:param traj_tdf_acc_state: No help available
		"""
		param = Conversions.bool_to_str(traj_tdf_acc_state)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration:STATe {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration \n
		Snippet: value: float = driver.source.fsimulator.dsSimulation.user.rx.trajectory.tdf.macceleration.get_value() \n
		No command help available \n
			:return: traj_tdf_acc_max: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration?')
		return Conversions.str_to_float(response)

	def set_value(self, traj_tdf_acc_max: float) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration \n
		Snippet: driver.source.fsimulator.dsSimulation.user.rx.trajectory.tdf.macceleration.set_value(traj_tdf_acc_max = 1.0) \n
		No command help available \n
			:param traj_tdf_acc_max: No help available
		"""
		param = Conversions.decimal_value_to_str(traj_tdf_acc_max)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:TRAJectory:TDF:MACCeleration {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pmode:
	"""Pmode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pmode", core, parent)

	def set(self, power_mode: enums.PhichPwrMode, subframeNull=repcap.SubframeNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PHICh:PMODe \n
		Snippet: driver.source.bb.oneweb.downlink.subf.encc.phich.pmode.set(power_mode = enums.PhichPwrMode.CONSt, subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param power_mode: No help available
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')"""
		param = Conversions.enum_scalar_to_str(power_mode, enums.PhichPwrMode)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PHICh:PMODe {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default) -> enums.PhichPwrMode:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PHICh:PMODe \n
		Snippet: value: enums.PhichPwrMode = driver.source.bb.oneweb.downlink.subf.encc.phich.pmode.get(subframeNull = repcap.SubframeNull.Default) \n
		No command help available \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: power_mode: No help available"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PHICh:PMODe?')
		return Conversions.str_to_scalar_enum(response, enums.PhichPwrMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Select:
	"""Select commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("select", core, parent)

	def set(self, user_list_select: str, objectIx=repcap.ObjectIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:OBJect<CH>:ULISt:SELect \n
		Snippet: driver.source.regenerator.object.ulist.select.set(user_list_select = '1', objectIx = repcap.ObjectIx.Default) \n
		Loads the selected list from the default or the specified directory. Loaded are files with extension *.reg_list. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in a
		specific directory.
			INTRO_CMD_HELP: The following applies POWer = RF output level + OFFSet, where: \n
			- Query the existing list with [:SOURce<hw>]:REGenerator:OBJect:ULISt:CATalog?
			- Apply the list with [:SOURce<hw>]:REGenerator:OBJect<ch>:ULISt:STATe \n
			:param user_list_select: 'filename' Filename or complete file path; file extension can be omitted
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')"""
		param = Conversions.value_to_quoted_str(user_list_select)
		objectIx_cmd_val = self._base.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:OBJect{objectIx_cmd_val}:ULISt:SELect {param}')

	def get(self, objectIx=repcap.ObjectIx.Default) -> str:
		"""SCPI: [SOURce<HW>]:REGenerator:OBJect<CH>:ULISt:SELect \n
		Snippet: value: str = driver.source.regenerator.object.ulist.select.get(objectIx = repcap.ObjectIx.Default) \n
		Loads the selected list from the default or the specified directory. Loaded are files with extension *.reg_list. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in a
		specific directory.
			INTRO_CMD_HELP: The following applies POWer = RF output level + OFFSet, where: \n
			- Query the existing list with [:SOURce<hw>]:REGenerator:OBJect:ULISt:CATalog?
			- Apply the list with [:SOURce<hw>]:REGenerator:OBJect<ch>:ULISt:STATe \n
			:param objectIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Object')
			:return: user_list_select: 'filename' Filename or complete file path; file extension can be omitted"""
		objectIx_cmd_val = self._base.get_repcap_cmd_value(objectIx, repcap.ObjectIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:REGenerator:OBJect{objectIx_cmd_val}:ULISt:SELect?')
		return trim_str_response(response)



from .............Internal.Core import Core
from .............Internal.CommandsGroup import CommandsGroup
from .............Internal import Conversions
from ............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Knull:
	"""Knull commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("knull", core, parent)

	def set(self, td_alloc_12_k_0: int, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:CELL<ST0>:DL:BWP<DIR0>:PDSCh:DC12:TD<GRP0>:KNULl \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.dc12.td.knull.set(td_alloc_12_k_0 = 1, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		No command help available \n
			:param td_alloc_12_k_0: No help available
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Td')"""
		param = Conversions.decimal_value_to_str(td_alloc_12_k_0)
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:DC12:TD{allocationNull_cmd_val}:KNULl {param}')

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, allocationNull=repcap.AllocationNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<CH0>:CELL<ST0>:DL:BWP<DIR0>:PDSCh:DC12:TD<GRP0>:KNULl \n
		Snippet: value: int = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.pdsch.dc12.td.knull.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, allocationNull = repcap.AllocationNull.Default) \n
		No command help available \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Td')
			:return: td_alloc_12_k_0: No help available"""
		userNull_cmd_val = self._base.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._base.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:PDSCh:DC12:TD{allocationNull_cmd_val}:KNULl?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rab:
	"""Rab commands group definition. 5 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rab", core, parent)

	@property
	def mac(self):
		"""mac commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mac'):
			from .Mac import Mac
			self._mac = Mac(self._core, self._base)
		return self._mac

	# noinspection PyTypeChecker
	def get_length(self) -> enums.EvdoRabLen:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:LENGth \n
		Snippet: value: enums.EvdoRabLen = driver.source.bb.evdo.anetwork.rab.get_length() \n
		Sets the duration (in slots) of a Reverse Activity bit. Note: This parameter is available for physical layer subtype 0&1
		only. \n
			:return: length: RL8| RL16| RL32| RL64
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:LENGth?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoRabLen)

	def set_length(self, length: enums.EvdoRabLen) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:LENGth \n
		Snippet: driver.source.bb.evdo.anetwork.rab.set_length(length = enums.EvdoRabLen.RL16) \n
		Sets the duration (in slots) of a Reverse Activity bit. Note: This parameter is available for physical layer subtype 0&1
		only. \n
			:param length: RL8| RL16| RL32| RL64
		"""
		param = Conversions.enum_scalar_to_str(length, enums.EvdoRabLen)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:LENGth {param}')

	def get_level(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:LEVel \n
		Snippet: value: float = driver.source.bb.evdo.anetwork.rab.get_level() \n
		Sets the power within the MAC block for the Reverse Activity channel. \n
			:return: level: float Range: -25 to -7
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:LEVel \n
		Snippet: driver.source.bb.evdo.anetwork.rab.set_level(level = 1.0) \n
		Sets the power within the MAC block for the Reverse Activity channel. \n
			:param level: float Range: -25 to -7
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:LEVel {param}')

	def get_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:OFFSet \n
		Snippet: value: int = driver.source.bb.evdo.anetwork.rab.get_offset() \n
		Sets the starting time offset of the Reverse Activity bit in slots. The command is specified in Reverse Activity Length/8
		units. The RA bit starts when the following equation is satisfied: System Time mod RAB length = RAB Offset, where System
		Time is expressed in slots. Note: This parameter is available for physical layer subtype 0&1 only. \n
			:return: offset: integer Range: 0 to 7
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:OFFSet?')
		return Conversions.str_to_int(response)

	def set_offset(self, offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:OFFSet \n
		Snippet: driver.source.bb.evdo.anetwork.rab.set_offset(offset = 1) \n
		Sets the starting time offset of the Reverse Activity bit in slots. The command is specified in Reverse Activity Length/8
		units. The RA bit starts when the following equation is satisfied: System Time mod RAB length = RAB Offset, where System
		Time is expressed in slots. Note: This parameter is available for physical layer subtype 0&1 only. \n
			:param offset: integer Range: 0 to 7
		"""
		param = Conversions.decimal_value_to_str(offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:OFFSet {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:STATe \n
		Snippet: value: bool = driver.source.bb.evdo.anetwork.rab.get_state() \n
		Activates or deactivates the reverse activity bit (RAB) . \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:ANETwork:RAB:STATe \n
		Snippet: driver.source.bb.evdo.anetwork.rab.set_state(state = False) \n
		Activates or deactivates the reverse activity bit (RAB) . \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:ANETwork:RAB:STATe {param}')

	def clone(self) -> 'Rab':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rab(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tps:
	"""Tps commands group definition. 4 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tps", core, parent)

	@property
	def id(self):
		"""id commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_id'):
			from .Id import Id
			self._id = Id(self._core, self._base)
		return self._id

	@property
	def mfec(self):
		"""mfec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mfec'):
			from .Mfec import Mfec
			self._mfec = Mfec(self._core, self._base)
		return self._mfec

	@property
	def tslicing(self):
		"""tslicing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tslicing'):
			from .Tslicing import Tslicing
			self._tslicing = Tslicing(self._core, self._base)
		return self._tslicing

	def clone(self) -> 'Tps':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tps(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sbas:
	"""Sbas commands group definition. 12 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sbas", core, parent)

	@property
	def egnos(self):
		"""egnos commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_egnos'):
			from .Egnos import Egnos
			self._egnos = Egnos(self._core, self._base)
		return self._egnos

	@property
	def gagan(self):
		"""gagan commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_gagan'):
			from .Gagan import Gagan
			self._gagan = Gagan(self._core, self._base)
		return self._gagan

	@property
	def msas(self):
		"""msas commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_msas'):
			from .Msas import Msas
			self._msas = Msas(self._core, self._base)
		return self._msas

	@property
	def waas(self):
		"""waas commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_waas'):
			from .Waas import Waas
			self._waas = Waas(self._core, self._base)
		return self._waas

	def clone(self) -> 'Sbas':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sbas(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPy:
	"""ListPy commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("listPy", core, parent)

	def get_all(self) -> List[int]:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID:BEIDou:LIST:ALL \n
		Snippet: value: List[int] = driver.source.bb.gnss.svid.beidou.listPy.get_all() \n
		Queries the SV IDs of all satellites of the GNSS system. The query lists SV IDs of the satellites included in and
		excluded from the satellite constellation (Figure 'Satellites constellation: Understanding the displayed information') . \n
			:return: id_pi_db_gnss_sat_sv_id_list_all: No help available
		"""
		response = self._core.io.query_bin_or_ascii_int_list('SOURce<HwInstance>:BB:GNSS:SVID:BEIDou:LIST:ALL?')
		return response

	def get_valid(self) -> List[int]:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID:BEIDou:LIST:[VALid] \n
		Snippet: value: List[int] = driver.source.bb.gnss.svid.beidou.listPy.get_valid() \n
		Queries the SV IDs of all valid satellites for the GNSS system. The query lists SV IDs of the satellites included in the
		satellite constellation. \n
			:return: gnss_sat_sv_id_list: No help available
		"""
		response = self._core.io.query_bin_or_ascii_int_list('SOURce<HwInstance>:BB:GNSS:SVID:BEIDou:LIST:VALid?')
		return response



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frc:
	"""Frc commands group definition. 10 total commands, 10 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frc", core, parent)

	@property
	def alResunits(self):
		"""alResunits commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_alResunits'):
			from .AlResunits import AlResunits
			self._alResunits = AlResunits(self._core, self._base)
		return self._alResunits

	@property
	def bpresUnit(self):
		"""bpresUnit commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bpresUnit'):
			from .BpresUnit import BpresUnit
			self._bpresUnit = BpresUnit(self._core, self._base)
		return self._bpresUnit

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import Modulation
			self._modulation = Modulation(self._core, self._base)
		return self._modulation

	@property
	def nnPrep(self):
		"""nnPrep commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nnPrep'):
			from .NnPrep import NnPrep
			self._nnPrep = NnPrep(self._core, self._base)
		return self._nnPrep

	@property
	def nosCarriers(self):
		"""nosCarriers commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_nosCarriers'):
			from .NosCarriers import NosCarriers
			self._nosCarriers = NosCarriers(self._core, self._base)
		return self._nosCarriers

	@property
	def paSize(self):
		"""paSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_paSize'):
			from .PaSize import PaSize
			self._paSize = PaSize(self._core, self._base)
		return self._paSize

	@property
	def scSpacing(self):
		"""scSpacing commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scSpacing'):
			from .ScSpacing import ScSpacing
			self._scSpacing = ScSpacing(self._core, self._base)
		return self._scSpacing

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def tbssIndex(self):
		"""tbssIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tbssIndex'):
			from .TbssIndex import TbssIndex
			self._tbssIndex = TbssIndex(self._core, self._base)
		return self._tbssIndex

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePy
			self._typePy = TypePy(self._core, self._base)
		return self._typePy

	def clone(self) -> 'Frc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePy:
	"""TypePy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("typePy", core, parent)

	def set(self, frc_id: enums.FrcTypeAll, userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:NIOT:FRC:TYPE \n
		Snippet: driver.source.bb.eutra.uplink.ue.niot.frc.typePy.set(frc_id = enums.FrcTypeAll.A141, userEquipment = repcap.UserEquipment.Default) \n
		Selects the FRC. \n
			:param frc_id: A141| A142| A143| A151| A144| A152| A161| A162| A163| A164| A165| A241| A242| A243| A244| A245| A246| A247
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')"""
		param = Conversions.enum_scalar_to_str(frc_id, enums.FrcTypeAll)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:NIOT:FRC:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self, userEquipment=repcap.UserEquipment.Default) -> enums.FrcTypeAll:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:NIOT:FRC:TYPE \n
		Snippet: value: enums.FrcTypeAll = driver.source.bb.eutra.uplink.ue.niot.frc.typePy.get(userEquipment = repcap.UserEquipment.Default) \n
		Selects the FRC. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: frc_id: A141| A142| A143| A151| A144| A152| A161| A162| A163| A164| A165| A241| A242| A243| A244| A245| A246| A247"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:NIOT:FRC:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FrcTypeAll)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZpDelta:
	"""ZpDelta commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zpDelta", core, parent)

	def get(self, cellNull=repcap.CellNull.Default, csiRefSignal=repcap.CsiRefSignal.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:DRS:CELL<CH0>:CSIRs<ST>:ZPDelta \n
		Snippet: value: int = driver.source.bb.eutra.downlink.drs.cell.csirs.zpDelta.get(cellNull = repcap.CellNull.Default, csiRefSignal = repcap.CsiRefSignal.Default) \n
		Queries the subframe offset ΔCSI-RS value. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param csiRefSignal: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Csirs')
			:return: sf_offset: integer Range: 0 to 80"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		csiRefSignal_cmd_val = self._base.get_repcap_cmd_value(csiRefSignal, repcap.CsiRefSignal)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:DRS:CELL{cellNull_cmd_val}:CSIRs{csiRefSignal_cmd_val}:ZPDelta?')
		return Conversions.str_to_int(response)
